@@ -73,4 +73,10 @@ public class CardinalityDataStructureYanMin extends
         return MinWatchCard.minWatchCardNew(this.solver, getVocabulary(),
                 literals, MinWatchCard.ATLEAST, degree);
     }
+
+    public Constr createUnregisteredCardinalityConstraint(IVecInt literals,
+            int degree) {
+        return new MinWatchCard(getVocabulary(), literals,
+                MinWatchCard.ATLEAST, degree);
+    }
 }
