@@ -80,7 +80,7 @@ public final class MaxWatchCard implements Propagatable, Constr, Undoable,
      * @param learnt
      *            indique si la contrainte est apprise
      */
-    private MaxWatchCard(ILits voc, IVecInt ps, boolean moreThan, int degree) {
+    public MaxWatchCard(ILits voc, IVecInt ps, boolean moreThan, int degree) {
 
         // On met en place les valeurs
         this.voc = voc;
@@ -265,7 +265,7 @@ public final class MaxWatchCard implements Propagatable, Constr, Undoable,
     /**
      * On normalise la contrainte au sens de Barth
      */
-    public final void normalize() {
+    public void normalize() {
         // Gestion du signe
         if (!this.moreThan) {
             // On multiplie le degr? par -1
@@ -452,4 +452,8 @@ public final class MaxWatchCard implements Propagatable, Constr, Undoable,
     public Constr toConstraint() {
         return this;
     }
+
+    public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
+        throw new UnsupportedOperationException("Not implemented yet!");
+    }
 }
