@@ -252,7 +252,6 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
      * @see Constr#locked()
      */
     public boolean locked() {
-        // TODO locked
         return true;
     }
 
@@ -623,4 +622,8 @@ public class MinWatchCard implements Propagatable, Constr, Undoable,
     public Constr toConstraint() {
         return this;
     }
+
+    public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
+        throw new UnsupportedOperationException("Not implemented yet!");
+    }
 }
