@@ -306,4 +306,8 @@ public abstract class HTClause implements Propagatable, Constr, Serializable {
     public Constr toConstraint() {
         return this;
     }
+
+    public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
+        calcReason(p, outReason);
+    }
 }
