@@ -29,6 +29,7 @@
  *******************************************************************************/
 package org.sat4j.minisat.core;
 
+import static org.sat4j.core.LiteralsUtils.neg;
 import static org.sat4j.core.LiteralsUtils.toDimacs;
 import static org.sat4j.core.LiteralsUtils.toInternal;
 import static org.sat4j.core.LiteralsUtils.var;
@@ -48,6 +49,8 @@ import org.sat4j.core.Vec;
 import org.sat4j.core.VecInt;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IConstr;
+import org.sat4j.specs.ILogAble;
+import org.sat4j.specs.ISolver;
 import org.sat4j.specs.ISolverService;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
@@ -71,20 +74,20 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
 
     private static final double CLAUSE_RESCALE_BOUND = 1 / CLAUSE_RESCALE_FACTOR;
 
-    protected ICDCLLogger out;
+    protected ILogAble out;
 
     /**
      * Set of original constraints.
      */
-    protected final IVec<Constr> constrs = new Vec<Constr>(); // Constr
+    protected final IVec<Constr> constrs = new Vec<Constr>();
 
     /**
      * Set of learned constraints.
      */
-    protected final IVec<Constr> learnts = new Vec<Constr>(); // Clause
+    protected final IVec<Constr> learnts = new Vec<Constr>();
 
     /**
-     * incr?ment pour l'activit? des clauses.
+     * Increment for clause activity.
      */
     private double claInc = 1.0;
 
@@ -94,29 +97,23 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
     private double claDecay = 1.0;
 
     /**
-     * Queue de propagation
+     * propagation queue
      */
     // head of the queue in trail ... (taken from MiniSAT 1.14)
     private int qhead = 0;
 
-    // queue
-
     /**
-     * affectation en ordre chronologique
+     * variable assignments (literals) in chronological order.
      */
-    protected final IVecInt trail = new VecInt(); // lit
-
-    // vector
+    protected final IVecInt trail = new VecInt();
 
     /**
-     * indice des s?parateurs des diff?rents niveau de d?cision dans trail
+     * position of the decision levels on the trail.
      */
-    protected final IVecInt trailLim = new VecInt(); // int
-
-    // vector
+    protected final IVecInt trailLim = new VecInt();
 
     /**
-     * S?pare les hypoth?ses incr?mentale et recherche
+     * position of assumptions before starting the search.
      */
     protected int rootLevel;
 
@@ -196,17 +193,18 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
 
     public Solver(LearningStrategy<D> learner, D dsf, SearchParams params,
             IOrder order, RestartStrategy restarter) {
-        this(learner, dsf, params, order, restarter, ICDCLLogger.CONSOLE);
+        this(learner, dsf, params, order, restarter, ILogAble.CONSOLE);
     }
 
     public Solver(LearningStrategy<D> learner, D dsf, SearchParams params,
-            IOrder order, RestartStrategy restarter, ICDCLLogger logger) {
-        this.learner = learner;
+            IOrder order, RestartStrategy restarter, ILogAble logger) {
         this.order = order;
         this.params = params;
-        setDataStructureFactory(dsf);
         this.restarter = restarter;
         this.out = logger;
+        setDataStructureFactory(dsf);
+        // should be called after dsf has been set up
+        setLearningStrategy(learner);
     }
 
     /*
@@ -264,8 +262,23 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
      * @see org.sat4j.minisat.core.ICDCL#setLearner(org.sat4j.minisat.core.
      * LearningStrategy)
      */
-    public void setLearner(LearningStrategy<D> learner) {
-        this.learner = learner;
+    public void setLearner(LearningStrategy<D> strategy) {
+        setLearningStrategy(strategy);
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.sat4j.minisat.core.ICDCL#setLearningStrategy(org.sat4j.minisat.core.
+     * LearningStrategy)
+     */
+    public void setLearningStrategy(LearningStrategy<D> strategy) {
+        if (this.learner != null) {
+            this.learner.setSolver(null);
+        }
+        this.learner = strategy;
+        strategy.setSolver(this);
     }
 
     public void setTimeout(int t) {
@@ -293,6 +306,10 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         this.params = sp;
     }
 
+    public SearchParams getSearchParams() {
+        return this.params;
+    }
+
     /*
      * (non-Javadoc)
      * 
@@ -1014,9 +1031,8 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
     /**
      * @return null if not conflict is found, else a conflicting constraint.
      */
-    public Constr propagate() {
+    public final Constr propagate() {
         IVecInt ltrail = this.trail;
-        ILits lvoc = this.voc;
         SolverStats lstats = this.stats;
         IOrder lorder = this.order;
         SearchListener lslistener = this.slistener;
@@ -1091,7 +1107,7 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
     }
 
     /**
-     * Revert to the state before the last push()
+     * Revert to the state before the last assume()
      */
     private void cancel() {
         // assert trail.size() == qhead || !undertimeout;
@@ -1166,7 +1182,9 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
                 assert nAssigns() <= this.voc.realnVars();
                 if (nAssigns() == this.voc.realnVars()) {
                     modelFound();
-                    this.slistener.solutionFound(this.model);
+                    this.slistener
+                            .solutionFound((this.fullmodel != null) ? this.fullmodel
+                                    : this.model, this);
                     if (this.sharedConflict == null) {
                         cancelUntil(this.rootLevel);
                         return Lbool.TRUE;
@@ -1286,7 +1304,7 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
                 if (!this.voc.isUnassigned(p)) {
                     tempmodel.push(this.voc.isSatisfied(p) ? i : -i);
                     this.userbooleanmodel[i - 1] = this.voc.isSatisfied(p);
-                    if (this.voc.getReason(p) == null) {
+                    if (this.voc.getReason(p) == null && voc.getLevel(p) > 0) {
                         this.decisions.push(tempmodel.last());
                     } else {
                         this.implied.push(tempmodel.last());
@@ -1313,75 +1331,117 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
             }
             this.fullmodel = new int[tempmodel.size()];
             tempmodel.moveTo(this.fullmodel);
+        } else {
+            this.fullmodel = this.model;
         }
     }
 
+    /**
+     * Forget a variable in the formula by falsifying both its positive and
+     * negative literals.
+     * 
+     * @param var
+     *            a variable
+     * @return a conflicting constraint resulting from the disparition of those
+     *         literals.
+     */
     private Constr forget(int var) {
+        boolean satisfied = this.voc.isSatisfied(toInternal(var));
         this.voc.forgets(var);
-        Constr confl = reduceClausesForFalsifiedLiteral(LiteralsUtils
-                .toInternal(var));
-        if (confl != null) {
-            return confl;
+        Constr confl;
+        if (satisfied) {
+            confl = reduceClausesForFalsifiedLiteral(LiteralsUtils
+                    .toInternal(-var));
+        } else {
+            confl = reduceClausesForFalsifiedLiteral(LiteralsUtils
+                    .toInternal(var));
         }
-        confl = reduceClausesForFalsifiedLiteral(LiteralsUtils.toInternal(-var));
         return confl;
     }
 
+    /**
+     * Assume literal p and perform unit propagation
+     * 
+     * @param p
+     *            a literal
+     * @return true if no conflict is reached, false if a conflict is found.
+     */
     private boolean setAndPropagate(int p) {
-        return assume(p) && propagate() == null;
+        if (voc.isUnassigned(p)) {
+            assert !trail.contains(p);
+            assert !trail.contains(neg(p));
+            return assume(p) && propagate() == null;
+        }
+        return voc.isSatisfied(p);
     }
 
     private int[] prime;
 
     public int[] primeImplicant() {
-        assert this.qhead == this.trail.size()
-                || this.qhead == this.learnedLiterals.size();
+        assert this.qhead == this.trail.size() + this.learnedLiterals.size();
         if (this.learnedLiterals.size() > 0) {
-            this.qhead = 0;
+            this.qhead = trail.size();
         }
-        this.prime = new int[this.implied.size() + this.decisions.size() + 1];
-        int p;
+        System.out.printf("%s implied: %d, decision: %d %n", getLogPrefix(),
+                implied.size(), decisions.size());
+        this.prime = new int[realNumberOfVariables() + 1];
+        int p, d;
         for (int i = 0; i < this.prime.length; i++) {
             this.prime[i] = 0;
         }
+        boolean noproblem;
         for (IteratorInt it = this.implied.iterator(); it.hasNext();) {
-            p = it.next();
-            this.prime[Math.abs(p)] = p;
-            setAndPropagate(toInternal(p));
+            d = it.next();
+            p = toInternal(d);
+            this.prime[Math.abs(d)] = d;
+            noproblem = setAndPropagate(p);
+            assert noproblem;
         }
-        int d;
-        boolean ok;
+        boolean canBeRemoved;
         int rightlevel;
         int removed = 0;
+        int propagated = 0;
+        int tested = 0;
+        int l2propagation = 0;
+
         for (int i = 0; i < this.decisions.size(); i++) {
             d = this.decisions.get(i);
+            assert !this.voc.isFalsified(toInternal(d));
             if (this.voc.isSatisfied(toInternal(d))) {
                 // d has been propagated
                 this.prime[Math.abs(d)] = d;
+                propagated++;
             } else if (setAndPropagate(toInternal(-d))) {
-                ok = true;
+                canBeRemoved = true;
+                tested++;
                 rightlevel = currentDecisionLevel();
                 for (int j = i + 1; j < this.decisions.size(); j++) {
+                    l2propagation++;
                     if (!setAndPropagate(toInternal(this.decisions.get(j)))) {
-                        ok = false;
+                        canBeRemoved = false;
                         break;
                     }
                 }
                 cancelUntil(rightlevel);
-                if (ok) {
+                if (canBeRemoved) {
                     // it is not a necessary literal
                     forget(Math.abs(d));
+                    IConstr confl = propagate();
+                    assert confl == null;
                     removed++;
                 } else {
                     this.prime[Math.abs(d)] = d;
                     cancel();
-                    setAndPropagate(toInternal(d));
+                    assert voc.isUnassigned(toInternal(d));
+                    noproblem = setAndPropagate(toInternal(d));
+                    assert noproblem;
                 }
             } else {
                 // conflict, literal is necessary
                 this.prime[Math.abs(d)] = d;
                 cancel();
-                setAndPropagate(toInternal(d));
+                noproblem = setAndPropagate(toInternal(d));
+                assert noproblem;
             }
         }
         cancelUntil(0);
@@ -1392,6 +1452,14 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
                 implicant[index++] = i;
             }
         }
+        if (isVerbose()) {
+            System.out.printf("%s prime implicant computation statistics%n",
+                    getLogPrefix());
+            System.out
+                    .printf("%s implied: %d, decision: %d (removed %d, tested %d, propagated %d), l2 propagation:%d%n",
+                            getLogPrefix(), implied.size(), decisions.size(),
+                            removed, tested, propagated, l2propagation);
+        }
         return implicant;
     }
 
@@ -1428,7 +1496,7 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         this.learnedLiterals.clear();
     }
 
-    protected void reduceDB() {
+    protected final void reduceDB() {
         this.stats.reduceddb++;
         this.slistener.cleaning();
         this.learnedConstraintsDeletionStrategy.reduce(this.learnts);
@@ -1930,7 +1998,7 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
             }
         }
         if (!global || firstTimeGlobal) {
-            this.restarter.init(this.params);
+            this.restarter.init(this.params, this.stats);
             this.timebegin = System.currentTimeMillis();
         }
         this.needToReduceDB = false;
@@ -1963,7 +2031,14 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         if (status == Lbool.UNDEFINED && !this.lastConflictMeansUnsat) {
             throw new TimeoutException("Cannot decide the satisfiability");
         }
-        return status == Lbool.TRUE;
+        // When using a search enumerator (to compute all models)
+        // the final answer is FALSE, however we are aware of at least one model
+        // (the last one)
+        return model != null;
+    }
+
+    public void printInfos(PrintWriter out) {
+        printInfos(out, prefix);
     }
 
     public void printInfos(PrintWriter out, String prefix) {
@@ -2120,6 +2195,10 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         printStat(new PrintWriter(out, true), prefix);
     }
 
+    public void printStat(PrintWriter out) {
+        printStat(out, prefix);
+    }
+
     public void printStat(PrintWriter out, String prefix) {
         this.stats.printStat(out, prefix);
         double cputime = (System.currentTimeMillis() - this.timebegin) / 1000;
@@ -2166,6 +2245,10 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
             stb.append("Heuristics kept accross calls (keep the solver \"hot\")\n");
             stb.append(prefix);
         }
+        stb.append("Listener: ");
+        stb.append(slistener);
+        stb.append("\n");
+        stb.append(prefix);
         stb.append("--- End Solver configuration ---"); //$NON-NLS-1$
         return stb.toString();
     }
@@ -2324,7 +2407,7 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         expireTimeout();
     }
 
-    private Constr sharedConflict;
+    protected Constr sharedConflict;
 
     /**
      * @since 2.3.2
@@ -2381,11 +2464,11 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         this.needToReduceDB = needToReduceDB;
     }
 
-    public void setLogger(ICDCLLogger out) {
+    public void setLogger(ILogAble out) {
         this.out = out;
     }
 
-    public ICDCLLogger getLogger() {
+    public ILogAble getLogger() {
         return this.out;
     }
 
@@ -2428,17 +2511,17 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
      */
     public void setLearnedConstraintsDeletionStrategy(
             LearnedConstraintsEvaluationType evaluation) {
-        ConflictTimer timer = this.learnedConstraintsDeletionStrategy
+        ConflictTimer aTimer = this.learnedConstraintsDeletionStrategy
                 .getTimer();
         switch (evaluation) {
         case ACTIVITY:
-            this.learnedConstraintsDeletionStrategy = activityBased(timer);
+            this.learnedConstraintsDeletionStrategy = activityBased(aTimer);
             break;
         case LBD:
-            this.learnedConstraintsDeletionStrategy = new GlucoseLCDS(timer);
+            this.learnedConstraintsDeletionStrategy = new GlucoseLCDS(aTimer);
             break;
         case LBD2:
-            this.learnedConstraintsDeletionStrategy = new Glucose2LCDS(timer);
+            this.learnedConstraintsDeletionStrategy = new Glucose2LCDS(aTimer);
             break;
         }
         if (this.conflictCount != null) {
@@ -2454,8 +2537,55 @@ public class Solver<D extends DataStructureFactory> implements ISolverService,
         this.keepHot = keepHot;
     }
 
-    public void addClause(int[] literals) {
-        throw new UnsupportedOperationException("Not implemented yet");
+    public IConstr addClauseOnTheFly(int[] literals) {
+        IVecInt clause = new VecInt(literals.length);
+        for (int d : literals) {
+            clause.push(LiteralsUtils.toInternal(d));
+        }
+        this.sharedConflict = this.dsfactory.createUnregisteredClause(clause);
+        this.sharedConflict.register();
+        addConstr(this.sharedConflict);
+        IVecInt reason = new VecInt();
+        this.sharedConflict.calcReasonOnTheFly(ILits.UNDEFINED, trail, reason);
+        while (!trail.isEmpty() && !reason.contains(trail.last())) {
+            undoOne();
+            if (!trailLim.isEmpty() && trailLim.last() == trail.size()) {
+                trailLim.pop();
+            }
+        }
+        return this.sharedConflict;
+    }
 
+    public ISolver getSolvingEngine() {
+        return this;
+    }
+
+    /**
+     * 
+     * @param literals
+     */
+    public IConstr addAtMostOnTheFly(int[] literals, int degree) {
+        IVecInt clause = new VecInt(literals.length);
+        for (int d : literals) {
+            clause.push(LiteralsUtils.toInternal(-d));
+        }
+        IVecInt copy = new VecInt(clause.size());
+        clause.copyTo(copy);
+        this.sharedConflict = this.dsfactory
+                .createUnregisteredCardinalityConstraint(copy, literals.length
+                        - degree);
+        this.sharedConflict.register();
+        addConstr(this.sharedConflict);
+        // backtrack to the first decision level with a reason
+        // for falsifying that constraint
+        IVecInt reason = new VecInt();
+        this.sharedConflict.calcReasonOnTheFly(ILits.UNDEFINED, trail, reason);
+        while (!trail.isEmpty() && !reason.contains(trail.last())) {
+            undoOne();
+            if (!trailLim.isEmpty() && trailLim.last() == trail.size()) {
+                trailLim.pop();
+            }
+        }
+        return this.sharedConflict;
     }
 }
