@@ -1,10 +1,10 @@
 /*******************************************************************************
- * SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
+ * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ *  http://www.eclipse.org/legal/epl-v10.html
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU Lesser General Public License Version 2.1 or later (the
@@ -15,15 +15,17 @@
  * the provisions above and replace them with the notice and other provisions
  * required by the LGPL. If you do not delete the provisions above, a recipient
  * may use your version of this file under the terms of the EPL or the LGPL.
- * 
+ *
  * Based on the original MiniSat specification from:
- * 
+ *
  * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
  * Sixth International Conference on Theory and Applications of Satisfiability
  * Testing, LNCS 2919, pp 502-518, 2003.
  *
  * See www.minisat.se for the original solver in C++.
- * 
+ *
+ * Contributors:
+ *   CRIL - initial API and implementation
  *******************************************************************************/
 package org.sat4j.minisat.orders;
 
@@ -36,25 +38,25 @@ import static org.sat4j.core.LiteralsUtils.var;
  * 
  */
 public final class PhaseInLastLearnedClauseSelectionStrategy extends
-		AbstractPhaserecordingSelectionStrategy {
+        AbstractPhaserecordingSelectionStrategy {
 
-	/**
+    /**
      * 
      */
-	private static final long serialVersionUID = 1L;
+    private static final long serialVersionUID = 1L;
 
-	public void updateVar(int p) {
-		phase[var(p)] = p;
-	}
+    public void updateVar(int p) {
+        this.phase[var(p)] = p;
+    }
 
-	@Override
-	public String toString() {
-		return "phase appearing in latest learned clause";
-	}
+    @Override
+    public String toString() {
+        return "phase appearing in latest learned clause";
+    }
 
-	public void assignLiteral(int p) {
-	}
+    public void assignLiteral(int p) {
+    }
 
-	public void updateVarAtDecisionLevel(int q) {
-	}
+    public void updateVarAtDecisionLevel(int q) {
+    }
 }
