@@ -34,8 +34,6 @@ import java.io.PrintWriter;
 import java.io.Serializable;
 import java.util.Map;
 
-import org.sat4j.tools.ModelIterator;
-
 /**
  * This interface contains all services provided by a SAT solver.
  * 
@@ -257,7 +255,7 @@ public interface ISolver extends IProblem, Serializable {
      * of the solver should be the same across different architecture.
      * 
      * @param count
-     *            the timeout (in number of counflicts)
+     *            the timeout (in number of conflicts)
      */
     void setTimeoutOnConflicts(int count);
 
@@ -292,6 +290,11 @@ public interface ISolver extends IProblem, Serializable {
 
     /**
      * Clean up the internal state of the solver.
+     * 
+     * Note that such method should also be called when you no longer need the
+     * solver because the state of the solver may prevent the GC to proceed.
+     * There is a known issue for instance where failing to call reset() on a
+     * solver will keep timer threads alive and exhausts memory.
      */
     void reset();
 
@@ -314,9 +317,22 @@ public interface ISolver extends IProblem, Serializable {
      * @param prefix
      *            the prefix to put in front of each line
      * @since 1.6
+     * @deprecated using the prefix does no longer makes sense because the
+     *             solver owns it.
      */
+    @Deprecated
     void printStat(PrintWriter out, String prefix);
 
+    /**
+     * Display statistics to the given output writer
+     * 
+     * @param out
+     * @since 2.3.3
+     * 
+     * @see #setLogPrefix(String)
+     */
+    void printStat(PrintWriter out);
+
     /**
      * To obtain a map of the available statistics from the solver. Note that
      * some keys might be specific to some solvers.
@@ -441,7 +457,7 @@ public interface ISolver extends IProblem, Serializable {
      * @return an array of literals, in Dimacs format, corresponding to a model
      *         of the formula over all the variables declared in the solver.
      * @see #model()
-     * @see ModelIterator
+     * @see org.sat4j.tools.ModelIterator
      * @since 2.3.1
      */
     int[] modelWithInternalVariables();
@@ -483,4 +499,18 @@ public interface ISolver extends IProblem, Serializable {
      * @since 2.3.2
      */
     void setKeepSolverHot(boolean keepHot);
+
+    /**
+     * Retrieve the real engine in case the engine is decorated by one or
+     * several decorator. This can be used for instance to setup the engine,
+     * which requires to bypass all the decorators.
+     * 
+     * It is thus safe to downcast the ISolver to an ICDCL interface. We cannot
+     * directly return an ICDCL object because we are not on the same
+     * abstraction level here.
+     * 
+     * @return the solver
+     * @since 2.3.3
+     */
+    ISolver getSolvingEngine();
 }
