@@ -29,6 +29,8 @@
  *******************************************************************************/
 package org.sat4j.tools;
 
+import java.io.PrintWriter;
+
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IConstr;
 import org.sat4j.specs.IVecInt;
@@ -96,7 +98,7 @@ public class DimacsStringSolver extends AbstractOutputSolver {
     public IConstr addClause(IVecInt literals) throws ContradictionException {
         if (this.firstConstr) {
             if (!this.fixedNbClauses) {
-                this.firstCharPos = 7 + Integer.toString(this.nbvars).length();
+                this.firstCharPos = 0;
                 this.out.append("                    ");
                 this.out.append("\n");
                 this.nbclauses = 0;
@@ -223,4 +225,20 @@ public class DimacsStringSolver extends AbstractOutputSolver {
     public boolean primeImplicant(int p) {
         throw new UnsupportedOperationException();
     }
+
+    /**
+     * @since 2.3.3
+     */
+    public void printStat(PrintWriter out) {
+        throw new UnsupportedOperationException();
+
+    }
+
+    /**
+     * @since 2.3.3
+     */
+    public void printInfos(PrintWriter out) {
+        throw new UnsupportedOperationException();
+
+    }
 }
