@@ -34,6 +34,7 @@ import java.io.PrintWriter;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import org.sat4j.core.ASolverFactory;
 import org.sat4j.core.ConstrGroup;
@@ -78,7 +79,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
     protected final int numberOfSolvers;
     private int winnerId;
     private boolean resultFound;
-    private volatile int remainingSolvers;
+    private AtomicInteger remainingSolvers;
     private volatile int sleepTime;
     private volatile boolean solved;
 
@@ -206,7 +207,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
     public void printStat(PrintStream out, String prefix) {
         for (int i = 0; i < this.numberOfSolvers; i++) {
             out.printf(
-                    "%s>>>>>>>>>> Solver number %d (%d answers) <<<<<<<<<<<<<<<<<<\n",
+                    "%s>>>>>>>>>> Solver number %d (%d answers) <<<<<<<<<<<<<<<<<<%n",
                     prefix, i, this.solversStats.get(i).getValue());
             this.solvers.get(i).printStat(out, prefix);
         }
@@ -215,7 +216,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
     public void printStat(PrintWriter out, String prefix) {
         for (int i = 0; i < this.numberOfSolvers; i++) {
             out.printf(
-                    "%s>>>>>>>>>> Solver number %d (%d answers) <<<<<<<<<<<<<<<<<<\n",
+                    "%s>>>>>>>>>> Solver number %d (%d answers) <<<<<<<<<<<<<<<<<<%n",
                     prefix, i, this.solversStats.get(i).getValue());
             this.solvers.get(i).printStat(out, prefix);
         }
@@ -311,7 +312,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
 
     public synchronized boolean isSatisfiable(IVecInt assumps,
             boolean globalTimeout) throws TimeoutException {
-        this.remainingSolvers = this.numberOfSolvers;
+        this.remainingSolvers = new AtomicInteger(this.numberOfSolvers);
         this.solved = false;
         for (int i = 0; i < this.numberOfSolvers; i++) {
             new Thread(new RunnableSolver(i, this.solvers.get(i), assumps,
@@ -321,12 +322,12 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
             this.sleepTime = NORMAL_SLEEP;
             do {
                 wait(this.sleepTime);
-            } while (this.remainingSolvers > 0);
+            } while (this.remainingSolvers.get() > 0);
         } catch (InterruptedException e) {
             // will happen when one solver found a solution
         }
         if (!this.solved) {
-            assert this.remainingSolvers == 0;
+            assert this.remainingSolvers.get() == 0;
             throw new TimeoutException();
         }
         return this.resultFound;
@@ -358,7 +359,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
 
     public void printInfos(PrintWriter out, String prefix) {
         for (int i = 0; i < this.numberOfSolvers; i++) {
-            out.printf("%s>>>>>>>>>> Solver number %d <<<<<<<<<<<<<<<<<<\n",
+            out.printf("%s>>>>>>>>>> Solver number %d <<<<<<<<<<<<<<<<<<%n",
                     prefix, i);
             this.solvers.get(i).printInfos(out, prefix);
         }
@@ -380,7 +381,7 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
             System.out.println(getLogPrefix() + "And the winner is "
                     + this.availableSolvers[this.winnerId]);
         }
-        this.remainingSolvers--;
+        this.remainingSolvers.getAndDecrement();
     }
 
     public boolean isDBSimplificationAllowed() {
@@ -508,6 +509,29 @@ public class ManyCore<S extends ISolver> implements ISolver, OutcomeListener {
         }
 
     }
+
+    public ISolver getSolvingEngine() {
+        throw new UnsupportedOperationException("Not supported yet in ManyCore");
+    }
+
+    /**
+     * @since 2.3.3
+     */
+    public void printStat(PrintWriter out) {
+        printStat(out, getLogPrefix());
+    }
+
+    /**
+     * @since 2.3.3
+     */
+    public void printInfos(PrintWriter out) {
+        for (int i = 0; i < this.numberOfSolvers; i++) {
+            out.printf("%s>>>>>>>>>> Solver number %d <<<<<<<<<<<<<<<<<<%n",
+                    getLogPrefix(), i);
+            this.solvers.get(i).printInfos(out);
+        }
+
+    }
 }
 
 class RunnableSolver implements Runnable {
