@@ -83,6 +83,16 @@ public abstract class SolverDecorator<T extends ISolver> implements ISolver {
         this.solver.printInfos(out, prefix);
     }
 
+    /*
+     * (non-Javadoc)
+     * 
+     * @see org.sat4j.specs.IProblem#printInfos(java.io.PrintWriter,
+     * java.lang.String)
+     */
+    public void printInfos(PrintWriter out) {
+        this.solver.printInfos(out);
+    }
+
     /*
      * (non-Javadoc)
      * 
@@ -188,6 +198,10 @@ public abstract class SolverDecorator<T extends ISolver> implements ISolver {
         this.solver.printStat(out, prefix);
     }
 
+    public void printStat(PrintWriter out) {
+        this.solver.printStat(out);
+    }
+
     private T solver;
 
     /**
@@ -489,4 +503,11 @@ public abstract class SolverDecorator<T extends ISolver> implements ISolver {
         return this.solver.primeImplicant(p);
     }
 
+    /**
+     * @since 2.3.3
+     */
+    public ISolver getSolvingEngine() {
+        return this.solver.getSolvingEngine();
+    }
+
 }
