@@ -56,6 +56,11 @@ import org.sat4j.specs.IVecInt;
  */
 public class Binary extends EncodingStrategyAdapter {
 
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
+
     /**
      * p being the smaller integer greater than log_2(n), this encoding adds p
      * variables and n*p clauses.
@@ -70,14 +75,18 @@ public class Binary extends EncodingStrategyAdapter {
         final int p = (int) Math.ceil(Math.log(n) / Math.log(2));
         final int k = (int) Math.pow(2, p) - n;
 
+        IVecInt clause = new VecInt();
+        String binary = "";
+
+        if (p == 0) {
+            return group;
+        }
+
         int y[] = new int[p];
         for (int i = 0; i < p; i++) {
             y[i] = solver.nextFreeVarId(true);
         }
 
-        IVecInt clause = new VecInt();
-        String binary = "";
-
         for (int i = 0; i < k; i++) {
             binary = Integer.toBinaryString(i);
             while (binary.length() != p - 1) {
@@ -177,18 +186,6 @@ public class Binary extends EncodingStrategyAdapter {
         return group;
     }
 
-    @Override
-    public IConstr addAtLeast(ISolver solver, IVecInt literals, int k)
-            throws ContradictionException {
-
-        IVecInt newLits = new VecInt();
-        for (int i = 0; i < literals.size(); i++) {
-            newLits.push(-literals.get(i));
-        }
-
-        return addAtMost(solver, newLits, literals.size() - k);
-    }
-
     @Override
     public IConstr addExactlyOne(ISolver solver, IVecInt literals)
             throws ContradictionException {
