@@ -52,6 +52,11 @@ import org.sat4j.specs.IVecInt;
  */
 public class Binomial extends EncodingStrategyAdapter {
 
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
+
     @Override
     public IConstr addAtMost(ISolver solver, IVecInt literals, int degree)
             throws ContradictionException {
@@ -114,33 +119,4 @@ public class Binomial extends EncodingStrategyAdapter {
         return group;
     }
 
-    @Override
-    public IConstr addAtLeast(ISolver solver, IVecInt literals, int degree)
-            throws ContradictionException {
-        if (degree == 1) {
-            return addAtLeastOne(solver, literals);
-        }
-
-        IVecInt negLiterals = new VecInt();
-
-        for (int i = 0; i < literals.size(); i++) {
-            negLiterals.push(-literals.get(i));
-        }
-
-        return addAtMost(solver, negLiterals, literals.size() - degree);
-    }
-
-    @Override
-    public IConstr addAtLeastOne(ISolver solver, IVecInt literals)
-            throws ContradictionException {
-        ConstrGroup group = new ConstrGroup();
-        IVecInt clause = new VecInt();
-
-        for (int i = 0; i < literals.size(); i++) {
-            clause.push(literals.get(i));
-        }
-        group.add(solver.addClause(clause));
-
-        return group;
-    }
 }
