@@ -52,6 +52,11 @@ import org.sat4j.specs.IVecInt;
  */
 public class Sequential extends EncodingStrategyAdapter {
 
+    /**
+     * 
+     */
+    private static final long serialVersionUID = 1L;
+
     /**
      * This encoding adds (n-1)*k variables (n is the number of variables in the
      * at most constraint and k is the degree of the constraint) and 2nk+n-3k-1
@@ -63,6 +68,10 @@ public class Sequential extends EncodingStrategyAdapter {
         ConstrGroup group = new ConstrGroup(false);
         final int n = literals.size();
 
+        if (n == 1) {
+            return group;
+        }
+
         int s[][] = new int[n - 1][k];
         for (int j = 0; j < k; j++) {
             for (int i = 0; i < n - 1; i++) {
@@ -111,4 +120,32 @@ public class Sequential extends EncodingStrategyAdapter {
         return group;
     }
 
+    @Override
+    public IConstr addAtMostOne(ISolver solver, IVecInt literals)
+            throws ContradictionException {
+        return addAtMost(solver, literals, 1);
+    }
+
+    @Override
+    public IConstr addExactlyOne(ISolver solver, IVecInt literals)
+            throws ContradictionException {
+        ConstrGroup group = new ConstrGroup();
+
+        group.add(addAtLeastOne(solver, literals));
+        group.add(addAtMostOne(solver, literals));
+
+        return group;
+    }
+
+    @Override
+    public IConstr addExactly(ISolver solver, IVecInt literals, int degree)
+            throws ContradictionException {
+        ConstrGroup group = new ConstrGroup();
+
+        group.add(addAtLeast(solver, literals, degree));
+        group.add(addAtMost(solver, literals, degree));
+
+        return group;
+    }
+
 }
