@@ -29,19 +29,25 @@
  *******************************************************************************/
 package org.sat4j.maxsat;
 
+import java.io.IOException;
+
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.HelpFormatter;
 import org.apache.commons.cli.Options;
 import org.apache.commons.cli.ParseException;
 import org.apache.commons.cli.PosixParser;
 import org.sat4j.AbstractLauncher;
-import org.sat4j.AbstractOptimizationLauncher;
+import org.sat4j.ILauncherMode;
 import org.sat4j.maxsat.reader.WDimacsReader;
 import org.sat4j.opt.MinOneDecorator;
 import org.sat4j.pb.ConstraintRelaxingPseudoOptDecorator;
 import org.sat4j.pb.PseudoOptDecorator;
-import org.sat4j.reader.DimacsReader;
+import org.sat4j.pb.tools.SearchOptimizerListener;
+import org.sat4j.reader.LecteurDimacs;
+import org.sat4j.reader.ParseFormatException;
 import org.sat4j.reader.Reader;
+import org.sat4j.specs.ContradictionException;
+import org.sat4j.specs.IProblem;
 import org.sat4j.specs.ISolver;
 
 /**
@@ -51,32 +57,41 @@ import org.sat4j.specs.ISolver;
  * @since 2.0
  * 
  */
-public class GenericOptLauncher extends AbstractOptimizationLauncher {
+public class GenericOptLauncher extends AbstractLauncher {
 
     /**
      * 
      */
     private static final long serialVersionUID = 1L;
 
+    public GenericOptLauncher() {
+        setLauncherMode(ILauncherMode.OPTIMIZATION);
+    }
+
     @SuppressWarnings("nls")
     private Options createCLIOptions() {
         Options options = new Options();
+        options.addOption("s", "solver", true,
+                "specifies the name of a PB solver");
         options.addOption("t", "timeout", true,
                 "specifies the timeout (in seconds)");
         options.addOption("p", "parallel", false,
                 "uses CP and RES pseudo-boolean solvers in parallel");
         options.addOption("T", "timeoutms", true,
                 "specifies the timeout (in milliseconds)");
-        options.addOption("k", "kind", true,
+        options.addOption("K", "kind", true,
                 "kind of problem: minone, maxsat, etc.");
         options.addOption("i", "incomplete", false,
                 "incomplete mode for maxsat");
+        options.addOption("I", "inner mode", false, "optimize using inner mode");
         options.addOption("c", "clean databases", false,
                 "clean up the database at root level");
         options.addOption("k", "keep Hot", false,
                 "Keep heuristics accross calls to the SAT solver");
         options.addOption("e", "equivalence", false,
                 "Use an equivalence instead of an implication for the selector variables");
+        options.addOption("pi", "prime-implicant", false,
+                "Use prime implicants instead of models for evaluating the objective function");
         options.addOption("n", "no solution line", false,
                 "Do not display a solution line (useful if the solution is large)");
         options.addOption("l", "lower bounding", false,
@@ -102,12 +117,13 @@ public class GenericOptLauncher extends AbstractOptimizationLauncher {
         if (problemname.contains(".wcnf")) { //$NON-NLS-1$
             reader = new WDimacsReader(this.wmsd);
         } else {
-            reader = new DimacsReader(this.wmsd);
+            reader = new LecteurDimacs(aSolver);
         }
         reader.setVerbosity(true);
         return reader;
     }
 
+    
     @Override
     protected String getInstanceName(String[] args) {
         return args[args.length - 1];
@@ -122,18 +138,23 @@ public class GenericOptLauncher extends AbstractOptimizationLauncher {
         if (args.length == 0) {
             HelpFormatter helpf = new HelpFormatter();
             helpf.printHelp("java -jar sat4j-maxsat.jar", options, true);
+            System.exit(0);
         } else {
             try {
                 CommandLine cmd = new PosixParser().parse(options, args);
                 int problemindex = args.length - 1;
                 setDisplaySolutionLine(!cmd.hasOption("n"));
                 boolean equivalence = cmd.hasOption("e");
-                String kind = cmd.getOptionValue("k"); //$NON-NLS-1$
+                String kind = cmd.getOptionValue("K"); //$NON-NLS-1$
                 if (kind == null) {
                     kind = "maxsat";
                 }
+                String aPBSolverName = cmd.getOptionValue("s");
+                if (aPBSolverName==null) {
+                    aPBSolverName = "Default";
+                }
                 if ("minone".equalsIgnoreCase(kind)) {
-                    asolver = new MinOneDecorator(SolverFactory.newDefault());
+                    asolver = new MinOneDecorator(org.sat4j.minisat.SolverFactory.newDefault());
                 } else if ("mincost".equalsIgnoreCase(kind)
                         || args[problemindex].endsWith(".p2cnf")) {
                     asolver = new MinCostDecorator(SolverFactory.newDefault());
@@ -149,13 +170,18 @@ public class GenericOptLauncher extends AbstractOptimizationLauncher {
                                 equivalence);
                     } else {
                         this.wmsd = new WeightedMaxSatDecorator(
-                                SolverFactory.newDefault(), equivalence);
+                                org.sat4j.pb.SolverFactory.instance().createSolverByName(aPBSolverName), equivalence);
                     }
                     if (cmd.hasOption("l")) {
                         asolver = new ConstraintRelaxingPseudoOptDecorator(
                                 this.wmsd);
-                    } else {
-                        asolver = new PseudoOptDecorator(this.wmsd,false,!equivalence);
+                    } else if (cmd.hasOption("I")){
+                        this.wmsd.setSearchListener(new SearchOptimizerListener(ILauncherMode.DECISION));
+                        setLauncherMode(ILauncherMode.DECISION);
+                        asolver = this.wmsd;
+                    }else{
+                        asolver = new PseudoOptDecorator(this.wmsd, false,
+                                cmd.hasOption("pi"));
                     }
                 }
                 if (cmd.hasOption("i")) {
@@ -189,4 +215,12 @@ public class GenericOptLauncher extends AbstractOptimizationLauncher {
         AbstractLauncher lanceur = new GenericOptLauncher();
         lanceur.run(args);
     }
+
+    @Override
+    protected IProblem readProblem(String problemname)
+            throws ParseFormatException, IOException,
+            ContradictionException {
+        super.readProblem(problemname);
+        return solver;
+    }
 }
