@@ -36,6 +36,8 @@ import org.sat4j.core.VecInt;
 import org.sat4j.minisat.constraints.cnf.Clauses;
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.pb.constraints.pb.IDataStructurePB;
+import org.sat4j.pb.constraints.pb.MapPb;
+import org.sat4j.pb.constraints.pb.Pseudos;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVec;
 import org.sat4j.specs.IVecInt;
@@ -128,6 +130,44 @@ public abstract class AbstractPBClauseCardConstrDataStructure extends
         return constructLearntPB(dspb);
     }
 
+    /*
+     * (non-Javadoc)
+     * 
+     * @seeorg.sat4j.minisat.constraints.AbstractPBDataStructureFactory#
+     * constraintFactory(org.sat4j.specs.VecInt, org.sat4j.specs.VecInt, int)
+     */
+    private Constr learntConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree, boolean moreThan) {
+        int[] lits = new int[literals.size()];
+        literals.copyTo(lits);
+        BigInteger[] bc = new BigInteger[coefs.size()];
+        coefs.copyTo(bc);
+        degree = Pseudos.niceCheckedParametersForCompetition(lits, bc,
+                moreThan, degree);
+
+        if (degree.equals(BigInteger.ONE)) {
+            return constructLearntClause(new VecInt(lits));
+        }
+        if (coefficientsEqualToOne(bc)) {
+            return constructLearntCard(new VecInt(lits),
+                    new Vec<BigInteger>(bc), degree);
+        }
+        return constructLearntPB(new VecInt(lits), new Vec<BigInteger>(bc),
+                degree);
+    }
+
+    @Override
+    protected Constr learntAtLeastConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntConstraintFactory(literals, coefs, degree, true);
+    }
+
+    @Override
+    protected Constr learntAtMostConstraintFactory(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return learntConstraintFactory(literals, coefs, degree, false);
+    }
+
     static boolean coefficientsEqualToOne(BigInteger[] coefs) {
         for (int i = 0; i < coefs.length; i++) {
             if (!coefs[i].equals(BigInteger.ONE)) {
@@ -161,10 +201,22 @@ public abstract class AbstractPBClauseCardConstrDataStructure extends
         return this.icardc.constructLearntCard(getVocabulary(), dspb);
     }
 
+    protected Constr constructLearntCard(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return this.icardc.constructLearntCard(getVocabulary(), new MapPb(
+                literals, coefs, degree));
+    }
+
     protected Constr constructLearntPB(IDataStructurePB dspb) {
         return this.ipbc.constructLearntPB(getVocabulary(), dspb);
     }
 
+    protected Constr constructLearntPB(IVecInt literals,
+            IVec<BigInteger> coefs, BigInteger degree) {
+        return this.ipbc.constructLearntPB(getVocabulary(), new MapPb(literals,
+                coefs, degree));
+    }
+
     public static final BigInteger sumOfCoefficients(BigInteger[] coefs) {
         BigInteger sumCoefs = BigInteger.ZERO;
         for (BigInteger c : coefs) {
