@@ -34,6 +34,7 @@ import java.math.BigInteger;
 
 import org.sat4j.core.Vec;
 import org.sat4j.core.VecInt;
+import org.sat4j.minisat.constraints.card.AtLeast;
 import org.sat4j.minisat.constraints.card.MinWatchCard;
 import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.ILits;
@@ -55,7 +56,10 @@ public class MinCardConstructor implements ICardConstructor {
         IVecInt resLits = new VecInt();
         IVec<BigInteger> resCoefs = new Vec<BigInteger>();
         dspb.buildConstraintFromConflict(resLits, resCoefs);
-        return new MinWatchCard(voc, resLits, true, dspb.getDegree().intValue());
+        return new AtLeast(voc, resLits, dspb.getDegree().intValue());// MinWatchCard(voc,
+                                                                      // resLits,
+                                                                      // true,
+                                                                      // dspb.getDegree().intValue());
     }
 
 }
