@@ -420,7 +420,6 @@ public class MinWatchPbLong extends WatchPbLong {
         }
 
         assert this.learnt || maxCoef != 0;
-        // DLB assert maxCoef!=0;
         return maxCoef;
     }
 
@@ -445,7 +444,7 @@ public class MinWatchPbLong extends WatchPbLong {
 
             // we must obtain upWatchCumul such that
             // upWatchCumul = degree + maxCoef
-            long degreePlusMaxCoef = this.degree + maxCoef; // dvh
+            long degreePlusMaxCoef = this.degree + maxCoef;
             for (int ind = 0; ind < this.lits.length; ind++) {
                 if (upWatchCumul >= degreePlusMaxCoef) {
                     // nothing more to watch
@@ -465,9 +464,7 @@ public class MinWatchPbLong extends WatchPbLong {
                     // coefficient
                     if (this.coefs[ind] > maxCoef) {
                         maxCoef = this.coefs[ind];
-                        degreePlusMaxCoef = this.degree + maxCoef; // update
-                        // that one
-                        // too
+                        degreePlusMaxCoef = this.degree + maxCoef;
                     }
                 }
             }
