@@ -41,6 +41,7 @@ import org.sat4j.minisat.core.Undoable;
 import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.IteratorInt;
 
 /**
  * Abstract data structure for pseudo-boolean constraint with watched literals.
@@ -56,6 +57,7 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
 	 */
     private static final long serialVersionUID = 1L;
 
+    private static final int LIMIT_SELECTION_SORT = 15;
     /**
      * constraint activity
      */
@@ -113,7 +115,7 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
 
     /** Constructor used for original constraints. */
     WatchPb(int[] lits, BigInteger[] coefs, BigInteger degree,
-            BigInteger sumCoefs) { // NOPMD
+            BigInteger sumCoefs) {
         this.lits = lits;
         this.coefs = coefs;
         this.degree = degree;
@@ -178,9 +180,9 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
         }
     }
 
-    abstract protected void computeWatches() throws ContradictionException;
+    protected abstract void computeWatches() throws ContradictionException;
 
-    abstract protected void computePropagation(UnitPropagationListener s)
+    protected abstract void computePropagation(UnitPropagationListener s)
             throws ContradictionException;
 
     /**
@@ -347,25 +349,25 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
     }
 
     void selectionSort(int from, int to) {
-        int i, j, best_i;
+        int i, j, bestIndex;
         BigInteger tmp;
         int tmp2;
 
         for (i = from; i < to - 1; i++) {
-            best_i = i;
+            bestIndex = i;
             for (j = i + 1; j < to; j++) {
-                if (this.coefs[j].compareTo(this.coefs[best_i]) > 0
-                        || this.coefs[j].equals(this.coefs[best_i])
-                        && this.lits[j] > this.lits[best_i]) {
-                    best_i = j;
+                if (this.coefs[j].compareTo(this.coefs[bestIndex]) > 0
+                        || this.coefs[j].equals(this.coefs[bestIndex])
+                        && this.lits[j] > this.lits[bestIndex]) {
+                    bestIndex = j;
                 }
             }
             tmp = this.coefs[i];
-            this.coefs[i] = this.coefs[best_i];
-            this.coefs[best_i] = tmp;
+            this.coefs[i] = this.coefs[bestIndex];
+            this.coefs[bestIndex] = tmp;
             tmp2 = this.lits[i];
-            this.lits[i] = this.lits[best_i];
-            this.lits[best_i] = tmp2;
+            this.lits[i] = this.lits[bestIndex];
+            this.lits[bestIndex] = tmp2;
         }
     }
 
@@ -403,7 +405,7 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
     /**
      * sort coefficient and literal arrays
      */
-    final protected void sort() {
+    protected final void sort() {
         assert this.lits != null;
         if (this.coefs.length > 0) {
             this.sort(0, size());
@@ -424,9 +426,9 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
      * @param to
      *            index for the end of the sort
      */
-    final protected void sort(int from, int to) {
+    protected final void sort(int from, int to) {
         int width = to - from;
-        if (width <= 15) {
+        if (width <= LIMIT_SELECTION_SORT) {
             selectionSort(from, to);
         } else {
             int indPivot = width / 2 + from;
@@ -473,7 +475,6 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
 
         if (this.lits.length > 0) {
             for (int i = 0; i < this.lits.length; i++) {
-                // if (voc.isUnassigned(lits[i])) {
                 stb.append(" + ");
                 stb.append(this.coefs[i]);
                 stb.append(".");
@@ -484,7 +485,6 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
                 stb.append(this.voc.getLevel(this.lits[i]));
                 stb.append("]");
                 stb.append(" ");
-                // }
             }
             stb.append(">= ");
             stb.append(this.degree);
@@ -636,4 +636,22 @@ public abstract class WatchPb implements IWatchPb, Propagatable, Undoable,
     public Constr toConstraint() {
         return this;
     }
+
+    public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
+        BigInteger sumfalsified = BigInteger.ZERO;
+        IVecInt vlits = new VecInt(this.lits);
+        int index;
+        for (IteratorInt it = trail.iterator(); it.hasNext();) {
+            int q = it.next();
+            if (vlits.contains(q ^ 1)) {
+                assert voc.isFalsified(q ^ 1);
+                outReason.push(q);
+                index = vlits.indexOf(q ^ 1);
+                sumfalsified = sumfalsified.add(this.coefs[index]);
+                if (this.sumcoefs.subtract(sumfalsified).compareTo(this.degree) < 0) {
+                    return;
+                }
+            }
+        }
+    }
 }
