@@ -41,6 +41,7 @@ import org.sat4j.minisat.core.Undoable;
 import org.sat4j.minisat.core.UnitPropagationListener;
 import org.sat4j.specs.ContradictionException;
 import org.sat4j.specs.IVecInt;
+import org.sat4j.specs.IteratorInt;
 
 public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
         Serializable {
@@ -50,6 +51,7 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
 	 */
     private static final long serialVersionUID = 1L;
 
+    private static final int LIMIT_SELECTION_SORT = 15;
     /**
      * constraint activity
      */
@@ -108,7 +110,7 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
 
     /** Constructor used for original constraints. */
     WatchPbLong(int[] lits, BigInteger[] coefs, BigInteger degree,
-            BigInteger sumCoefs) { // NOPMD
+            BigInteger sumCoefs) {
         this.lits = lits;
         this.coefs = toLong(coefs);
         this.degree = degree.longValue();
@@ -189,9 +191,9 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
         }
     }
 
-    abstract protected void computeWatches() throws ContradictionException;
+    protected abstract void computeWatches() throws ContradictionException;
 
-    abstract protected void computePropagation(UnitPropagationListener s)
+    protected abstract void computePropagation(UnitPropagationListener s)
             throws ContradictionException;
 
     /**
@@ -346,25 +348,25 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
     }
 
     void selectionSort(int from, int to) {
-        int i, j, best_i;
+        int i, j, bestIndex;
         long tmp;
         int tmp2;
 
         for (i = from; i < to - 1; i++) {
-            best_i = i;
+            bestIndex = i;
             for (j = i + 1; j < to; j++) {
-                if (this.coefs[j] > this.coefs[best_i]
-                        || this.coefs[j] == this.coefs[best_i]
-                        && this.lits[j] > this.lits[best_i]) {
-                    best_i = j;
+                if (this.coefs[j] > this.coefs[bestIndex]
+                        || this.coefs[j] == this.coefs[bestIndex]
+                        && this.lits[j] > this.lits[bestIndex]) {
+                    bestIndex = j;
                 }
             }
             tmp = this.coefs[i];
-            this.coefs[i] = this.coefs[best_i];
-            this.coefs[best_i] = tmp;
+            this.coefs[i] = this.coefs[bestIndex];
+            this.coefs[bestIndex] = tmp;
             tmp2 = this.lits[i];
-            this.lits[i] = this.lits[best_i];
-            this.lits[best_i] = tmp2;
+            this.lits[i] = this.lits[bestIndex];
+            this.lits[bestIndex] = tmp2;
         }
     }
 
@@ -402,7 +404,7 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
     /**
      * sort coefficient and literal arrays
      */
-    final protected void sort() {
+    protected final void sort() {
         assert this.lits != null;
         if (this.coefs.length > 0) {
             this.sort(0, size());
@@ -422,9 +424,9 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
      * @param to
      *            index for the end of the sort
      */
-    final protected void sort(int from, int to) {
+    protected final void sort(int from, int to) {
         int width = to - from;
-        if (width <= 15) {
+        if (width <= LIMIT_SELECTION_SORT) {
             selectionSort(from, to);
         } else {
             int indPivot = width / 2 + from;
@@ -469,7 +471,6 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
 
         if (this.lits.length > 0) {
             for (int i = 0; i < this.lits.length; i++) {
-                // if (voc.isUnassigned(lits[i])) {
                 stb.append(" + ");
                 stb.append(this.coefs[i]);
                 stb.append(".");
@@ -480,7 +481,6 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
                 stb.append(this.voc.getLevel(this.lits[i]));
                 stb.append("]");
                 stb.append(" ");
-                // }
             }
             stb.append(">= ");
             stb.append(this.degree);
@@ -623,4 +623,23 @@ public abstract class WatchPbLong implements Propagatable, Constr, Undoable,
     public Constr toConstraint() {
         return this;
     }
+
+    public void calcReasonOnTheFly(int p, IVecInt trail, IVecInt outReason) {
+        long sumfalsified = 0;
+        IVecInt vlits = new VecInt(this.lits);
+        int index;
+        for (IteratorInt it = trail.iterator(); it.hasNext();) {
+            int q = it.next();
+            if (vlits.contains(q ^ 1)) {
+                assert voc.isFalsified(q ^ 1);
+                outReason.push(q);
+                index = vlits.indexOf(q ^ 1);
+                sumfalsified += coefs[index];
+                if (this.sumcoefs - sumfalsified < this.degree) {
+                    return;
+                }
+            }
+        }
+
+    }
 }
