@@ -41,7 +41,12 @@ package org.sat4j.sat;
  * If no solver name is given, then the default solver of the solver factory is
  * used (@see org.sat4j.core.ASolverFactory#defaultSolver()).
  * 
+ * This class is no longer used since 2.3.3 because it cannot launch maxsat problems.
+ * 
+ * @see Launcher
+ * 
  * @author sroussel
+ * 
  */
 
 import java.io.FileNotFoundException;
@@ -58,10 +63,9 @@ import org.apache.commons.cli.ParseException;
 import org.apache.commons.cli.PosixParser;
 import org.sat4j.AbstractLauncher;
 import org.sat4j.ExitCode;
-import org.sat4j.core.ASolverFactory;
+import org.sat4j.ILauncherMode;
 import org.sat4j.core.VecInt;
 import org.sat4j.minisat.core.ICDCL;
-import org.sat4j.minisat.core.ICDCLLogger;
 import org.sat4j.pb.IPBSolver;
 import org.sat4j.pb.PseudoOptDecorator;
 import org.sat4j.pb.core.IPBCDCLSolver;
@@ -70,6 +74,7 @@ import org.sat4j.reader.InstanceReader;
 import org.sat4j.reader.ParseFormatException;
 import org.sat4j.reader.Reader;
 import org.sat4j.specs.ContradictionException;
+import org.sat4j.specs.ILogAble;
 import org.sat4j.specs.IOptimizationProblem;
 import org.sat4j.specs.IProblem;
 import org.sat4j.specs.ISolver;
@@ -83,11 +88,14 @@ import org.sat4j.tools.FileBasedVisualizationTool;
 import org.sat4j.tools.LearnedClausesSizeTracing;
 import org.sat4j.tools.MultiTracing;
 
-public class Lanceur extends AbstractLauncher implements ICDCLLogger {
+@Deprecated
+public class Lanceur extends AbstractLauncher implements ILogAble {
+
+    private static final String NUMBER = "number";
 
     /**
-	 * 
-	 */
+     * 
+     */
     private static final long serialVersionUID = 1L;
 
     private static final String CURRENT_OPTIMUM_VALUE_PREFIX = "o "; //$NON-NLS-1$
@@ -97,13 +105,12 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
     private boolean isModeOptimization = false;
 
     private IProblem problem;
-    private ICDCL cdclSolver;
 
     private boolean modeTracing = false;
 
     private boolean launchRemoteControl;
 
-    static AbstractLauncher lanceur;
+    private static AbstractLauncher lanceur;
 
     public static void main(final String[] args) {
         lanceur = new Lanceur();
@@ -111,8 +118,6 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
 
     }
 
-    protected ASolverFactory<ISolver> factory;
-
     private String filename;
 
     private int k = -1;
@@ -148,11 +153,9 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
                         .forName("org.sat4j." + framework + ".SolverFactory"); //$NON-NLS-1$ //$NON-NLS-2$
                 Class<?>[] params = {};
                 Method m = clazz.getMethod("instance", params); //$NON-NLS-1$
-                this.factory = (ASolverFactory) m.invoke(null, (Object[]) null);
             } catch (Exception e) { // DLB Findbugs warning ok
                 log("Wrong framework: " + framework
                         + ". Using minisat instead.");
-                this.factory = org.sat4j.minisat.SolverFactory.instance();
             }
 
             ICDCL asolver = Solvers.configureSolver(args, this);
@@ -288,8 +291,7 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
 
     @Override
     protected IProblem readProblem(String problemname)
-            throws FileNotFoundException, ParseFormatException, IOException,
-            ContradictionException {
+            throws ParseFormatException, IOException, ContradictionException {
         ISolver theSolver = (ISolver) super.readProblem(problemname);
         if (this.k > 0) {
             IVecInt literals = new VecInt();
@@ -370,11 +372,11 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
         this.solver.printStat(out, COMMENT_PREFIX);
         this.solver.printInfos(out, COMMENT_PREFIX);
         ExitCode exitCode = getExitCode();
-        out.println(ANSWER_PREFIX + exitCode);
+        out.println(ILauncherMode.ANSWER_PREFIX + exitCode);
         if (exitCode == ExitCode.SATISFIABLE
                 || exitCode == ExitCode.OPTIMUM_FOUND || this.incomplete
                 && exitCode == ExitCode.UPPER_BOUND) {
-            out.print(SOLUTION_PREFIX);
+            out.print(ILauncherMode.SOLUTION_PREFIX);
             getReader().decode(this.problem.model(), out);
             out.println();
             if (this.isModeOptimization) {
@@ -390,8 +392,7 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
     public void run(String[] args) {
         try {
             displayHeader();
-            this.cdclSolver = configureSolver(args);
-            this.solver = this.cdclSolver;
+            this.solver = configureSolver(args);
             if (this.solver == null) {
                 usage();
                 return;
@@ -418,9 +419,6 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
                 }
                 System.exit(lanceur.getExitCode().value());
             } else {
-                // RemoteControlFrame frame = new RemoteControlFrame(filename,
-                // "",
-                // cdclSolver);
                 RemoteControlFrame frame = new RemoteControlFrame(
                         this.filename, "", args);
                 frame.activateTracing(this.modeTracing);
@@ -483,13 +481,13 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
         op = options.getOption("S");
         op.setArgName("solverStringDefinition");
         op = options.getOption("t");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("T");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("C");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("k");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("d");
         op.setArgName("filename");
         op = options.getOption("f");
@@ -497,7 +495,7 @@ public class Lanceur extends AbstractLauncher implements ICDCLLogger {
         op = options.getOption("r");
         op.setArgName("searchlistener");
         op = options.getOption("rw");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         return options;
     }
 
