@@ -2,13 +2,14 @@ package org.sat4j.sat;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 import java.util.StringTokenizer;
-import java.util.Vector;
 
 import org.apache.commons.beanutils.BeanUtils;
 import org.apache.commons.cli.CommandLine;
@@ -20,7 +21,6 @@ import org.apache.commons.cli.PosixParser;
 import org.sat4j.core.ASolverFactory;
 import org.sat4j.minisat.core.DataStructureFactory;
 import org.sat4j.minisat.core.ICDCL;
-import org.sat4j.minisat.core.ICDCLLogger;
 import org.sat4j.minisat.core.IOrder;
 import org.sat4j.minisat.core.IPhaseSelectionStrategy;
 import org.sat4j.minisat.core.LearnedConstraintsEvaluationType;
@@ -33,43 +33,57 @@ import org.sat4j.minisat.orders.RandomWalkDecorator;
 import org.sat4j.minisat.orders.VarOrderHeap;
 import org.sat4j.pb.orders.RandomWalkDecoratorObjective;
 import org.sat4j.pb.orders.VarOrderHeapObjective;
+import org.sat4j.specs.ILogAble;
 import org.sat4j.specs.ISolver;
+import org.sat4j.tools.DotSearchTracing;
 
-public class Solvers {
+public final class Solvers {
 
-    public final static String ORDERS = "ORDERS";
-    public final static String LEARNING = "LEARNING";
-    public final static String RESTARTS = "RESTARTS";
-    public final static String PHASE = "PHASE";
-    public final static String PARAMS = "PARAMS";
-    public final static String SIMP = "SIMP";
+    private static final String SEPARATOR = "-------------------";
+    private static final String CLASS = "class";
+    private static final String OPB = "opb";
+    private static final String CNF = "cnf";
+    private static final String MAXSAT = "maxsat";
+    private static final String OPT = "opt";
+    private static final String FILENAME = "filename";
+    private static final String NUMBER = "number";
+    private static final String PROBLEM_WITH_COMPONENT = "Problem with component ";
+    private static final String PB = "pb";
+    private static final String MINISAT = "minisat";
+    public static final String ORDERS = "ORDERS";
+    public static final String LEARNING = "LEARNING";
+    public static final String RESTARTS = "RESTARTS";
+    public static final String PHASE = "PHASE";
+    public static final String PARAMS = "PARAMS";
+    public static final String SIMP = "SIMP";
 
-    private final static String PACKAGE_ORDERS = "org.sat4j.minisat.orders";
-    private final static String PACKAGE_LEARNING = "org.sat4j.minisat.learning";
-    private final static String PACKAGE_RESTARTS = "org.sat4j.minisat.restarts";
-    private final static String PACKAGE_PHASE = "org.sat4j.minisat.orders";
-    private final static String PACKAGE_PARAMS = "org.sat4j.minisat.core";
+    private static final String PACKAGE_ORDERS = "org.sat4j.minisat.orders";
+    private static final String PACKAGE_LEARNING = "org.sat4j.minisat.learning";
+    private static final String PACKAGE_RESTARTS = "org.sat4j.minisat.restarts";
+    private static final String PACKAGE_PHASE = "org.sat4j.minisat.orders";
+    private static final String PACKAGE_PARAMS = "org.sat4j.minisat.core";
 
-    private final static String RESTART_STRATEGY_NAME = "org.sat4j.minisat.core.RestartStrategy";
-    private final static String ORDER_NAME = "org.sat4j.minisat.core.IOrder";
-    private final static String LEARNING_NAME = "org.sat4j.minisat.core.LearningStrategy";
-    private final static String PHASE_NAME = "org.sat4j.minisat.core.IPhaseSelectionStrategy";
-    private final static String PARAMS_NAME = "org.sat4j.minisat.core.SearchParams";
+    private static final String RESTART_STRATEGY_NAME = "org.sat4j.minisat.core.RestartStrategy";
+    private static final String ORDER_NAME = "org.sat4j.minisat.core.IOrder";
+    private static final String LEARNING_NAME = "org.sat4j.minisat.core.LearningStrategy";
+    private static final String PHASE_NAME = "org.sat4j.minisat.core.IPhaseSelectionStrategy";
+    private static final String PARAMS_NAME = "org.sat4j.minisat.core.SearchParams";
 
-    private final static Map<String, String> qualif = new HashMap<String, String>();
+    private static final Map<String, String> QUALIF = new HashMap<String, String>();
     static {
-        qualif.put(ORDERS, PACKAGE_ORDERS);
-        qualif.put(LEARNING, PACKAGE_LEARNING);
-        qualif.put(RESTARTS, PACKAGE_RESTARTS);
-        qualif.put(PHASE, PACKAGE_PHASE);
-        qualif.put(PARAMS, PACKAGE_PARAMS);
+        QUALIF.put(ORDERS, PACKAGE_ORDERS);
+        QUALIF.put(LEARNING, PACKAGE_LEARNING);
+        QUALIF.put(RESTARTS, PACKAGE_RESTARTS);
+        QUALIF.put(PHASE, PACKAGE_PHASE);
+        QUALIF.put(PARAMS, PACKAGE_PARAMS);
     }
 
     private Solvers() {
     }
 
-    protected final static ICDCL configureFromString(String solverconfig,
-            ICDCL theSolver, ICDCLLogger logger) {
+    protected static ICDCL configureFromString(String solverconfig,
+            ICDCL theSolver, ILogAble logger) {
+        assert theSolver != null;
         // AFAIK, there is no easy way to solve parameterized problems
         // when building the solver at runtime.
         StringTokenizer stk = new StringTokenizer(solverconfig, ",");
@@ -89,7 +103,7 @@ public class Solvers {
         }
         LearningStrategy learning = setupObject(LEARNING, pf, logger);
         if (learning != null) {
-            theSolver.setLearner(learning);
+            theSolver.setLearningStrategy(learning);
             learning.setSolver(aSolver);
         }
         IOrder order = setupObject(ORDERS, pf, logger);
@@ -129,11 +143,11 @@ public class Solvers {
         return theSolver;
     }
 
-    private final static <T> T setupObject(String component, Properties pf,
-            ICDCLLogger logger) {
+    private static <T> T setupObject(String component, Properties pf,
+            ILogAble logger) {
         try {
             String configline = pf.getProperty(component);
-            String qualification = qualif.get(component);
+            String qualification = QUALIF.get(component);
 
             if (configline == null) {
                 return null;
@@ -141,9 +155,8 @@ public class Solvers {
             if (qualification != null) {
                 logger.log("read " + qualification + "." + configline);
                 if (configline.contains("Objective")
-                        && qualification.contains("minisat")) {
-                    // log(qualification);
-                    qualification = qualification.replaceFirst("minisat", "pb");
+                        && qualification.contains(MINISAT)) {
+                    qualification = qualification.replaceFirst(MINISAT, PB);
                 }
                 configline = qualification + "." + configline;
             }
@@ -159,24 +172,27 @@ public class Solvers {
                     BeanUtils.getProperty(comp, param[0]);
                     BeanUtils.setProperty(comp, param[0], param[1]);
                 } catch (Exception e) {
-                    logger.log("Problem with component " + config[0] + " " + e);
+                    logger.log(PROBLEM_WITH_COMPONENT + config[0] + " " + e);
                 }
             }
             return comp;
         } catch (InstantiationException e) {
-            logger.log("Problem with component " + component + " " + e);
+            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
         } catch (IllegalAccessException e) {
-            logger.log("Problem with component " + component + " " + e);
+            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
         } catch (ClassNotFoundException e) {
-            logger.log("Problem with component " + component + " " + e);
+            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
         }
         return null;
     }
 
-    private static Options createCLIOptions() {
+    public static Options createCLIOptions() {
         Options options = new Options();
-        options.addOption("l", "library", true,
-                "specifies the name of the library used (minisat by default)");
+        options.addOption(
+                "l",
+                "library",
+                true,
+                "specifies the name of the library used (if not present, the library depends on the file extension)");
         options.addOption("s", "solver", true,
                 "specifies the name of a prebuilt solver from the library");
         options.addOption("S", "Solver", true,
@@ -189,23 +205,33 @@ public class Solvers {
                 "conflict based timeout (for deterministic behavior)");
         options.addOption("d", "dot", true,
                 "creates a sat4j.dot file in current directory representing the search");
-        options.addOption("f", "filename", true,
+        options.addOption("f", FILENAME, true,
                 "specifies the file to use (in conjunction with -d for instance)");
         options.addOption("m", "mute", false, "Set launcher in silent mode");
         options.addOption("k", "kleast", true,
                 "limit the search to models having at least k variables set to false");
-        options.addOption("r", "trace", false,
+        options.addOption("tr", "trace", false,
                 "traces the behavior of the solver");
-        options.addOption("opt", "optimize", false,
+        options.addOption(OPT, "optimize", false,
                 "uses solver in optimize mode instead of sat mode (default)");
         options.addOption("rw", "randomWalk", true,
                 "specifies the random walk probability ");
         options.addOption("remote", "remoteControl", false,
                 "launches remote control");
+        options.addOption("r", "trace", false,
+                "traces the behavior of the solver");
         options.addOption("H", "hot", false,
                 "keep the solver hot (do not reset heuristics) when a model is found");
         options.addOption("y", "simplify", false,
-                "simplify the set of clauses is possible");
+                "simplify the set of clauses if possible");
+        options.addOption("lo", "lower", false,
+                "search solution by lower bounding instead of by upper bounding");
+        options.addOption("e", "equivalence", false,
+                "Use an equivalence instead of an implication for the selector variables");
+        options.addOption("i", "incomplete", false,
+                "incomplete mode for maxsat");
+        options.addOption("n", "no solution line", false,
+                "Do not display a solution line (useful if the solution is large)");
         Option op = options.getOption("l");
         op.setArgName("libname");
         op = options.getOption("s");
@@ -213,85 +239,43 @@ public class Solvers {
         op = options.getOption("S");
         op.setArgName("solverStringDefinition");
         op = options.getOption("t");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("T");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("C");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("k");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         op = options.getOption("d");
-        op.setArgName("filename");
+        op.setArgName(FILENAME);
         op = options.getOption("f");
-        op.setArgName("filename");
-        op = options.getOption("r");
-        op.setArgName("searchlistener");
+        op.setArgName(FILENAME);
         op = options.getOption("rw");
-        op.setArgName("number");
+        op.setArgName(NUMBER);
         return options;
     }
 
-    // private static Map<String, String> createMapOptions(String args[]) {
-    // Map<String, String> options = new HashMap<String, String>();
-    //
-    // int i = 0;
-    // while (i < args.length) {
-    // if (args[i].equals("l") || args[i].equals("library")) {
-    // options.put("l", args[i + 1]);
-    // } else if (args[i].equals("s") || args[i].equals("solver")) {
-    // options.put("s", args[i + 1]);
-    // } else if (args[i].equals("S") || args[i].equals("Solver")) {
-    // options.put("S", args[i + 1]);
-    // } else if (args[i].equals("t") || args[i].equals("timeout")) {
-    // options.put("t", args[i + 1]);
-    // } else if (args[i].equals("T") || args[i].equals("timeoutms")) {
-    // options.put("T", args[i + 1]);
-    // } else if (args[i].equals("C") || args[i].equals("conflictbased")) {
-    // options.put("C", "true");
-    // } else if (args[i].equals("d") || args[i].equals("dot")) {
-    // options.put("d", args[i + 1]);
-    // } else if (args[i].equals("f") || args[i].equals("filename")) {
-    // options.put("f", args[i + 1]);
-    // } else if (args[i].equals("m") || args[i].equals("mute")) {
-    // options.put("m", "true");
-    // } else if (args[i].equals("k") || args[i].equals("kleast")) {
-    // options.put("k", args[i + 1]);
-    // }
-    //
-    // options.addOption("r", "trace", false,
-    // "traces the behavior of the solver");
-    // options.addOption("opt", "optimize", false,
-    // "uses solver in optimize mode instead of sat mode (default)");
-    // options.addOption("rw", "randomWalk", true,
-    // "specifies the random walk probability ");
-    // options.addOption("remote", "remoteControl", false,
-    // "launches remote control");
-    // options.addOption("H", "hot", false,
-    // "keep the solver hot (do not reset heuristics) when a model is found");
-    // options.addOption("y", "simplify", false,
-    // "simplify the set of clauses is possible");
-    // }
-    //
-    // return options;
-    // }
-
-    public static void stringUsage(ICDCLLogger logger) {
+    public static void stringUsage(ILogAble logger) {
         logger.log("Available building blocks: DSF, LEARNING, ORDERS, PHASE, RESTARTS, SIMP, PARAMS, CLEANING");
         logger.log("Example: -S RESTARTS=LubyRestarts/factor:512,LEARNING=MiniSATLearning");
     }
 
-    public static ICDCL configureSolver(String[] args, ICDCLLogger logger) {
+    public static boolean containsOptValue(String[] args) {
+        Options options = createCLIOptions();
+        try {
+            CommandLine cmd = new PosixParser().parse(options, args);
+            return cmd.hasOption(OPT);
+        } catch (ParseException e) {
+            return false;
+        }
+    }
+
+    public static ICDCL configureSolver(String[] args, ILogAble logger) {
         Options options = createCLIOptions();
         if (args.length == 0) {
             HelpFormatter helpf = new HelpFormatter();
             helpf.printHelp("java -jar sat4j.jar", options, true);
 
-            // log("Available solvers: "
-            // + Arrays.asList(factory.solverNames()));
-            // showAvailableLearning();
-            // showAvailableOrders();
-            // showAvailablePhase();
-            // showAvailableRestarts();
             return null;
         }
         try {
@@ -300,15 +284,31 @@ public class Solvers {
             boolean isModeOptimization = false;
             ASolverFactory<ISolver> factory;
 
-            if (cmd.hasOption("opt")) {
+            if (cmd.hasOption(OPT)) {
                 isModeOptimization = true;
             }
 
+            String filename = cmd.getOptionValue("f");
+
+            String[] rargs = cmd.getArgs();
+            if (filename == null && rargs.length > 0) {
+                filename = rargs[0];
+            }
+            String unzipped = uncompressed(filename);
+
             String framework = cmd.getOptionValue("l"); //$NON-NLS-1$
-            if (isModeOptimization) {
-                framework = "pb";
-            } else if (framework == null) {
-                framework = "minisat";
+            if (framework == null) {
+                if (isModeOptimization) {
+                    if (unzipped != null && unzipped.endsWith(CNF)) {
+                        framework = MAXSAT;
+                    } else {
+                        framework = PB;
+                    }
+                } else if (unzipped != null && unzipped.endsWith(OPB)) {
+                    framework = PB;
+                } else {
+                    framework = MINISAT;
+                }
             }
 
             try {
@@ -383,6 +383,18 @@ public class Solvers {
                 asolver.setDBSimplificationAllowed(true);
             }
 
+            if (cmd.hasOption("d")) {
+                String dotfilename = null;
+                if (filename != null) {
+                    dotfilename = cmd.getOptionValue("d");
+                }
+                if (dotfilename == null) {
+                    dotfilename = "sat4j.dot";
+                }
+                asolver.setSearchListener(new DotSearchTracing(dotfilename,
+                        null));
+            }
+
             return asolver;
         } catch (ParseException e1) {
             HelpFormatter helpf = new HelpFormatter();
@@ -392,9 +404,17 @@ public class Solvers {
         return null;
     }
 
-    public static void showAvailableRestarts(ICDCLLogger logger) {
-        Vector<String> classNames = new Vector<String>();
-        Vector<String> resultRTSI = RTSI.find(RESTART_STRATEGY_NAME);
+    public static String uncompressed(String filename) {
+        if (filename != null
+                && (filename.endsWith(".bz2") || filename.endsWith(".gz"))) {
+            return filename.substring(0, filename.lastIndexOf('.'));
+        }
+        return filename;
+    }
+
+    public static void showAvailableRestarts(ILogAble logger) {
+        List<String> classNames = new ArrayList<String>();
+        List<String> resultRTSI = RTSI.find(RESTART_STRATEGY_NAME);
         Set<String> keySet;
         for (String name : resultRTSI) {
             if (!name.contains("Remote")) {
@@ -405,32 +425,33 @@ public class Solvers {
                                             Solvers.PACKAGE_RESTARTS + "."
                                                     + name).newInstance())
                             .keySet();
-                    keySet.remove("class");
+                    keySet.remove(CLASS);
                     if (keySet.size() > 0) {
                         classNames.add(name + keySet);
                     } else {
                         classNames.add(name);
                     }
                 } catch (IllegalAccessException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InvocationTargetException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (NoSuchMethodException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InstantiationException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (ClassNotFoundException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 }
             }
         }
+        classNames.add("Glucose21Restarts");
         logger.log("Available restart strategies (" + Solvers.RESTARTS + "): "
                 + classNames);
     }
 
-    public static void showAvailablePhase(ICDCLLogger logger) {
-        Vector<String> classNames = new Vector<String>();
-        Vector<String> resultRTSI = RTSI.find(PHASE_NAME);
+    public static void showAvailablePhase(ILogAble logger) {
+        List<String> classNames = new ArrayList<String>();
+        List<String> resultRTSI = RTSI.find(PHASE_NAME);
         Set<String> keySet;
         for (String name : resultRTSI) {
             if (!name.contains("Remote")) {
@@ -439,22 +460,22 @@ public class Solvers {
                     keySet = BeanUtils.describe(
                             Class.forName(PACKAGE_PHASE + "." + name)
                                     .newInstance()).keySet();
-                    keySet.remove("class");
+                    keySet.remove(CLASS);
                     if (keySet.size() > 0) {
                         classNames.add(name + keySet);
                     } else {
                         classNames.add(name);
                     }
                 } catch (IllegalAccessException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InvocationTargetException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (NoSuchMethodException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InstantiationException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (ClassNotFoundException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 }
             }
         }
@@ -462,50 +483,49 @@ public class Solvers {
                 + classNames);
     }
 
-    public static void showAvailableLearning(ICDCLLogger logger) {
-        Vector<String> classNames = new Vector<String>();
-        Vector<String> resultRTSI = RTSI.find(LEARNING_NAME);
+    public static void showAvailableLearning(ILogAble logger) {
+        List<String> classNames = new ArrayList<String>();
+        List<String> resultRTSI = RTSI.find(LEARNING_NAME);
         Set<String> keySet;
         for (String name : resultRTSI) {
             try {
                 keySet = BeanUtils.describe(
                         Class.forName(PACKAGE_LEARNING + "." + name)
                                 .newInstance()).keySet();
-                keySet.remove("class");
+                keySet.remove(CLASS);
                 if (keySet.size() > 0) {
                     classNames.add(name + keySet);
                 } else {
                     classNames.add(name);
                 }
             } catch (IllegalAccessException e) {
-                e.printStackTrace();
+                logger.log(e.getMessage());
             } catch (InvocationTargetException e) {
-                e.printStackTrace();
+                logger.log(e.getMessage());
             } catch (NoSuchMethodException e) {
-                e.printStackTrace();
+                logger.log(e.getMessage());
             } catch (InstantiationException e) {
                 classNames.add(name);
             } catch (ClassNotFoundException e) {
-                e.printStackTrace();
+                logger.log(e.getMessage());
             } catch (NoClassDefFoundError cnfex) {
-                // System.out.println("Warning : no classDefFoundError : " +
-                // classname);
+                logger.log(cnfex.getMessage());
             }
         }
         logger.log("Available learning (" + Solvers.LEARNING + "): "
                 + classNames);
     }
 
-    public static void showAvailableOrders(ICDCLLogger logger) {
-        Vector<String> classNames = new Vector<String>();
-        Vector<String> resultRTSI = RTSI.find(ORDER_NAME);
+    public static void showAvailableOrders(ILogAble logger) {
+        List<String> classNames = new ArrayList<String>();
+        List<String> resultRTSI = RTSI.find(ORDER_NAME);
         Set<String> keySet = null;
         for (String name : resultRTSI) {
             if (!name.contains("Remote")) {
                 try {
                     if (name.contains("Objective")) {
                         String namePackage = Solvers.PACKAGE_ORDERS
-                                .replaceFirst("minisat", "pb");
+                                .replaceFirst(MINISAT, PB);
                         keySet = BeanUtils.describe(
                                 Class.forName(namePackage + "." + name)
                                         .newInstance()).keySet();
@@ -515,7 +535,7 @@ public class Solvers {
                                         Solvers.PACKAGE_ORDERS + "." + name)
                                         .newInstance()).keySet();
                     }
-                    keySet.remove("class");
+                    keySet.remove(CLASS);
 
                     if (keySet.size() > 0) {
                         classNames.add(name + keySet);
@@ -524,67 +544,60 @@ public class Solvers {
                     }
 
                 } catch (IllegalAccessException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InvocationTargetException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (NoSuchMethodException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 } catch (InstantiationException e) {
-                    // classNames.add(name);
+                    logger.log(e.getMessage());
                 } catch (ClassNotFoundException e) {
-                    e.printStackTrace();
+                    logger.log(e.getMessage());
                 }
             }
         }
         logger.log("Available orders (" + Solvers.ORDERS + "): " + classNames);
     }
 
-    public static void showParams(ICDCLLogger logger) {
+    public static void showParams(ILogAble logger) {
 
         Set<String> keySet = null;
         try {
             keySet = BeanUtils.describe(
                     Class.forName(PARAMS_NAME).newInstance()).keySet();
-            keySet.remove("class");
+            keySet.remove(CLASS);
         } catch (IllegalAccessException e) {
-            e.printStackTrace();
+            logger.log(e.getMessage());
         } catch (InvocationTargetException e) {
-            e.printStackTrace();
+            logger.log(e.getMessage());
         } catch (NoSuchMethodException e) {
-            e.printStackTrace();
+            logger.log(e.getMessage());
         } catch (InstantiationException e) {
-            e.printStackTrace();
+            logger.log(e.getMessage());
         } catch (ClassNotFoundException e) {
-            e.printStackTrace();
+            logger.log(e.getMessage());
         }
         logger.log("Available search params (" + Solvers.PARAMS
                 + "): [SearchParams" + keySet + "]");
     }
 
-    public static void showSimplifiers(ICDCLLogger logger) {
+    public static void showSimplifiers(ILogAble logger) {
         logger.log("Available simplifiers : [NO_SIMPLIFICATION, SIMPLE_SIMPLIFICATION, EXPENSIVE_SIMPLIFICATION]");
     }
 
     public static void showAvailableConstraintsCleaningStrategies(
-            ICDCLLogger logger) {
+            ILogAble logger) {
         logger.log("Available learned constraints cleaning strategies"
                 + Arrays.asList(LearnedConstraintsEvaluationType.values()));
     }
 
     public static <T extends ISolver> void showAvailableSolvers(
-            ASolverFactory<T> afactory, ICDCLLogger logger) {
-        // if (afactory != null) {
-        //			log("Available solvers: "); //$NON-NLS-1$
-        // String[] names = afactory.solverNames();
-        // for (int i = 0; i < names.length; i++) {
-        // log(names[i]);
-        // }
-        // }
+            ASolverFactory<T> afactory, ILogAble logger) {
         showAvailableSolvers(afactory, "", logger);
     }
 
     public static <T extends ISolver> void showAvailableSolvers(
-            ASolverFactory<T> afactory, String framework, ICDCLLogger logger) {
+            ASolverFactory<T> afactory, String framework, ILogAble logger) {
         if (afactory != null) {
             if (framework.length() > 0) {
                 logger.log("Available solvers for " + framework + ": "); //$NON-NLS-1$
@@ -598,21 +611,29 @@ public class Solvers {
         }
     }
 
-    public static void usage(ICDCLLogger logger) {
+    public static void usage(ILogAble logger) {
         ASolverFactory<ISolver> factory;
         factory = org.sat4j.minisat.SolverFactory.instance();
-        // log("SAT");
         showAvailableSolvers(factory, "sat", logger);
-        logger.log("-------------------");
+        logger.log(SEPARATOR);
         factory = (ASolverFactory) org.sat4j.pb.SolverFactory.instance();
-        // log("PB");
-        showAvailableSolvers(factory, "pb", logger);
+        showAvailableSolvers(factory, PB, logger);
+        logger.log(SEPARATOR);
+        factory = (ASolverFactory) org.sat4j.maxsat.SolverFactory.instance();
+        showAvailableSolvers(factory, MAXSAT, logger);
+        logger.log(SEPARATOR);
         showAvailableRestarts(logger);
+        logger.log(SEPARATOR);
         showAvailableOrders(logger);
+        logger.log(SEPARATOR);
         showAvailableLearning(logger);
+        logger.log(SEPARATOR);
         showAvailablePhase(logger);
+        logger.log(SEPARATOR);
         showParams(logger);
+        logger.log(SEPARATOR);
         showSimplifiers(logger);
+        logger.log(SEPARATOR);
         stringUsage(logger);
     }
 
